--------------------------
README file for PyICU_BiDi
--------------------------

.. contents::

Documentation
-------------

Please read the source.


Changelog
---------

2018-07-22 Version 0.0.3

Added Python 3 support.
Cleanups, but no functional changes.


2014-06-29 Version 0.0.2:

Various fixes, added support for Linux.


2014-06-26 Version 0.0.1:

Initial release by science + computing ag as open source.
Unfortunately almost completely undocumented. Tested only on
Windows. It does not work on Linux due to byte order problems.
